***********************
NengoEdge documentation
***********************

`NengoEdge <https://edge.nengo.ai/>`_ is a cloud-based platform for training and
deploying high accuracy, low power audio AI models on edge devices.

.. cssclass:: toc-cards toc-cards-narrow

   .. toctree::
      :maxdepth: 1

      tutorials/index
      faq
      developers

.. raw:: html

   <iframe width="560" height="315" src="https://www.youtube-nocookie.com/embed/vNfZuOU2nwM" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>

